@@ -1,11 +1,11 @@
 #' NEONiso: A package for calibrating NEON atmospheric isotope observations.
-#' 
+#'
 #' This package provides functions for retrieving, calibrating, and generating
 #' diagnostic plots of NEON atmospheric isotope data.
-#' 
+#'
 #' @docType package
 #' @name NEONiso
 NULL
 
 # suppress R CMD CHECK notes on variables that are internal to this package.
-globalVariables(c("..density..","level","varname","verticalPosition","dom","yr","mn"))
\ No newline at end of file
+globalVariables(c("..density..", "varname"))
\ No newline at end of file
