@@ -10,28 +10,28 @@
 #' @import tidyselect
 #' @import rlang
 extract_carbon_calibration_data <- function(data_list) {
-  
+
   # input should be the list from stackEddy
   if (!is.list(data_list)) {
     stop("Input to extract carbon calibration data must be a list")
   }
-  
+
   # extract desired data from data list.
-  data <- data_list %>% 
+  data <- data_list %>%
     dplyr::select("verticalPosition", "timeBgn", "timeEnd",
            tidyselect::starts_with("data.isoCo2.dlta13CCo2"),
            tidyselect::starts_with("data.isoCo2.rtioMoleDryCo2")) %>%
     dplyr::filter(.data$verticalPosition %in% c("co2High", "co2Med", "co2Low"))
     # uncertainty testing:
     #dplyr::filter(.data$verticalPosition %in% c("co2Low", "co2Med"))
-  
+
   # simplify names
   names(data) <- sub("data.isoCo2.", "", names(data))
-  
+
   #convert times to posixct
   data$timeBgn <- convert_NEONhdf5_to_POSIXct_time(data$timeBgn)
   data$timeEnd <- convert_NEONhdf5_to_POSIXct_time(data$timeEnd)
-  
+
   # return standard data frame.
   return(data)
 }
@@ -47,8 +47,8 @@ extract_carbon_calibration_data <- function(data_list) {
 #' @param data_list List containing data, from the /*/dp01/data/
 #'                  group in NEON HDF5 file.
 #' @param ucrt_list List containing uncertainty data, from the /*/dp01/ucrt/
-#'                  group in NEON HDF5 file. (only works if paired with ucrt_source = 'ucrt'
-#'                  and method = 'by_month')
+#'                  group in NEON HDF5 file. (only works if paired with
+#'                  ucrt_source = 'ucrt' and method = 'by_month')
 #' @param ucrt_source Where from HDF5 file should  variance be extracted from?
 #'                    (Only "data" works now..."ucrt" will throw an error.)
 #' @param method Are we calling this function from the calibrate_water_linreg
@@ -60,25 +60,25 @@ extract_carbon_calibration_data <- function(data_list) {
 extract_water_calibration_data <- function(data_list, ucrt_list = NULL,
                                            standard, ucrt_source = "data",
                                            method = "by_site") {
-  
+
   if (method == "by_site") {
-    
+
     if (ucrt_source == "ucrt") {
-      
-      stop("ucrt data handling not added yet...please change ucrt_source to 'data'")
-      
+
+      stop("ucrt handling not added yet...please change ucrt_source to 'data'")
+
     } else if (ucrt_source == "data") {
-      
+
       if (standard == "high") {
-        data <- subset(data_list, data_list$verticalPosition == 'h2oHigh')
+        data <- subset(data_list, data_list$verticalPosition == "h2oHigh")
       } else if (standard == "med") {
-        data <- subset(data_list, data_list$verticalPosition == 'h2oMed')
+        data <- subset(data_list, data_list$verticalPosition == "h2oMed")
       } else if (standard == "low") {
-        data <- subset(data_list, data_list$verticalPosition == 'h2oLow')
+        data <- subset(data_list, data_list$verticalPosition == "h2oLow")
       } else {
         stop()
       }
-      
+
       std_df  <- data.frame(d18O_meas_mean  = data_list$data.isoH2o.dlta18OH2o.mean,
                             d18O_meas_var   = data_list$data.isoH2o.dlta18OH2o.vari,
                             d18O_meas_n     = data_list$data.isoH2o.dlta18OH2o.numSamp,
@@ -93,18 +93,22 @@ extract_water_calibration_data <- function(data_list, ucrt_list = NULL,
                             d2H_ref_n       = data_list$data.isoH2o.dlta2HH2oRefe.numSamp,
                             btime           = data_list$timeBgn,
                             etime           = data_list$timeEnd)
-      
+
       #convert times to posixct
-      std_df$btime <- as.POSIXct(std_df$btime, format = "%Y-%m-%dT%H:%M:%OSZ", tz = "UTC")
-      std_df$etime <- as.POSIXct(std_df$etime, format = "%Y-%m-%dT%H:%M:%OSZ", tz = "UTC")
-      
+      std_df$btime <- as.POSIXct(std_df$btime,
+                                 format = "%Y-%m-%dT%H:%M:%OSZ",
+                                 tz = "UTC")
+      std_df$etime <- as.POSIXct(std_df$etime,
+                                 format = "%Y-%m-%dT%H:%M:%OSZ",
+                                 tz = "UTC")
+
       #kludge fix here - need to fix time variables in a future release!!
       std_df$d18O_meas_btime <- std_df$btime
 
     } # ucrt source
-    
+
   } else if (method == "by_month") {
-    
+
     if (standard == "high") {
       data <- data_list
     } else if (standard == "med") {
@@ -114,13 +118,13 @@ extract_water_calibration_data <- function(data_list, ucrt_list = NULL,
     } else {
       stop()
     }
-    
+
     if (ucrt_source == "ucrt") {
-      
-      stop("ucrt data handling not added yet...please change ucrt_source to 'data'")
-      
+
+      stop("ucrt handling not added yet...please change ucrt_source to 'data'")
+
     } else if (ucrt_source == "data") {
-      
+
       std_df <- data.frame(d18O_meas_mean = data$dlta18OH2o$mean,
                            d18O_meas_var = data$dlta18OH2o$vari,
                            d18O_meas_n = data$dlta18OH2o$numSamp,
@@ -141,7 +145,7 @@ extract_water_calibration_data <- function(data_list, ucrt_list = NULL,
                            d2H_ref_n = data$dlta2HH2oRefe$numSamp,
                            d2H_ref_btime = data$dlta2HH2oRefe$timeBgn,
                            d2H_ref_etime = data$dlta2HH2oRefe$timeEnd)
-      
+
       # change class of time variables from charatcter to posixct.
       std_df$d18O_meas_btime <- convert_NEONhdf5_to_POSIXct_time(std_df$d18O_meas_btime)
       std_df$d18O_meas_etime <- convert_NEONhdf5_to_POSIXct_time(std_df$d18O_meas_etime)
@@ -154,16 +158,16 @@ extract_water_calibration_data <- function(data_list, ucrt_list = NULL,
 
       std_df$d2H_ref_btime <- convert_NEONhdf5_to_POSIXct_time(std_df$d2H_ref_btime)
       std_df$d2H_ref_etime <- convert_NEONhdf5_to_POSIXct_time(std_df$d2H_ref_etime)
-      
+
     }
   } else {
     stop("no other methods have been coded")
   }
-  
+
   # add standard name
   std_df <- std_df %>%
     dplyr::mutate(std_name = standard)
-  
+
   return(std_df)
-  
+
 }
